# Pubmed

## search

### API search

To add a pubmed API search, enter the query in the [Pubmed web interface](https://pubmed.ncbi.nlm.nih.gov/), run the search, copy the url and run:

```
colrev search -a colrev.pubmed -p "https://pubmed.ncbi.nlm.nih.gov/?term=fitbit"
```

## prep

PubMed linking

## Links

- [Data field descriptions](https://www.nlm.nih.gov/bsd/mms/medlineelements.html)
- [Pubmed](https://pubmed.ncbi.nlm.nih.gov/)
